*Coming soon.*

In the meantime, you can take a look at the sample uses in the `examples/` directory, which show all the core functionality.

Requirements: Python >= 3.10

Name is pronounced "PLAY-doh", it's catchy, playful, and easy to say - according to ChatGPT.
